@@ -38,7 +38,7 @@ class Server(object):
         self.ai_task_client = save_task.task_client
         self.server_control['operation'] = ''
         self.board_change = 0
-        self.yaml_file = 'a.yaml'
+        self.yaml_file = os.path.join(BASE_DIR, 'a.yaml')
         self.bc = board_manager.BoardConfig(self.yaml_file)
         self.bc.read_yaml()
         self.ql = queuelib.QueueLib()
@@ -168,7 +168,9 @@ class Server(object):
             usb_wifi_type = msg['message_content']['dvb_info']['auto_board']['usb_wifi_type']
             priority = msg['message_content']['dvb_info']['auto_board']['priority']
             secure = msg['message_content']['dvb_info']['auto_board']['secure']
+            print(11111111111111111111111)
             if msg['message_content']['dvb_ai'] == 'ai':
+                print(21111111111111111111111)
                 board = msg['message_content']['ai_info']['task_info']['board']
                 idle_boards = self.bc.get_idle_board_list(arch, chip, board, signal, usb_type)
             else:
@@ -176,6 +178,7 @@ class Server(object):
                         usb_device, usb_gxbus, usb_type, usb_partition_num, \
                         web, usb_wifi, usb_wifi_type, secure, priority)
             print(idle_boards)
+            print(31111111111111111111111)
             if len(idle_boards) > 0:
                 use_board = idle_boards.pop()
                 client_ip = use_board[0]
